@@ -1,3 +1,6 @@
 # Insert your code here. 
 def helloworld_Kk():
-    print("Kk, hello world!")
\ No newline at end of file
+    print("Kk, hello world!")
+
+def multiply(a, b):
+    print(a*b)
\ No newline at end of file
